//[mahjong-utils](../../../../index.md)/[mahjongutils.models](../../index.md)/[Mentsu](../index.md)/[Companion](index.md)/[parse](parse.md)

# parse

[common]\
fun [parse](parse.md)(tiles: [List](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)&lt;[Tile](../../-tile/index.md)&gt;): [Mentsu](../index.md)

根据给定牌构造面子

#### Return

面子

#### Parameters

common

| | |
|---|---|
| tiles | 牌 |

[common]\
fun [parse](parse.md)(text: [String](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)): [Mentsu](../index.md)

根据给定牌构造面子

#### Return

面子

#### Parameters

common

| | |
|---|---|
| text | 牌的文本 |
